@@ -76,7 +76,7 @@ class BigQueryPipeline:
         if spider.settings.get("BIGQUERY_ADD_SCRAPER_NAME", False):
             item["scraper"] = spider.name
         if spider.settings.get("BIGQUERY_ADD_SCRAPER_SESSION", False):
-            item["scraper_session_id"] = spider.name
+            item["scraper_session_id"] = self.session_id
         for key in item:
             if isinstance(item[key], datetime.datetime):
                 item[key] = str(item[key])
